@@ -1,12 +1,12 @@
 /*
-  SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "filtermailmangziptest.h"
-#include <MailImporter/FilterMailmanGzip>
 #include "filterimportertest.h"
+#include <MailImporter/FilterMailmanGzip>
 #include <QTest>
 
 FilterMAilmangzipTest::FilterMAilmangzipTest(QObject *parent)
@@ -26,7 +26,7 @@ void FilterMAilmangzipTest::canNotImportDataEmptyPath()
 {
     MailImporter::FilterMailmanGzip filter;
     MailImporter::FilterInfo info;
-    auto *importerTest = new FilterImporterTest(&info);
+    auto importerTest = new FilterImporterTest(&info);
     filter.setFilterImporter(importerTest);
     filter.setFilterInfo(&info);
     filter.importMails(QStringList());
@@ -36,7 +36,7 @@ void FilterMAilmangzipTest::canNotImportDataEmptyPath()
 
 void FilterMAilmangzipTest::canNotImportDataUnknowPath()
 {
-    //VERIFY it.
+    // VERIFY it.
 #if 0
     MailImporter::FilterMailmanGzip filter;
     MailImporter::FilterInfo *info = new MailImporter::FilterInfo;
@@ -49,3 +49,5 @@ void FilterMAilmangzipTest::canNotImportDataUnknowPath()
 }
 
 QTEST_MAIN(FilterMAilmangzipTest)
+
+#include "moc_filtermailmangziptest.cpp"
