@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -23,13 +23,12 @@ class MAILIMPORTER_EXPORT FilterImporterBase
 public:
     explicit FilterImporterBase(MailImporter::FilterInfo *info);
     virtual ~FilterImporterBase();
-    Q_REQUIRED_RESULT virtual bool
-    importMessage(const QString &folderName, const QString &msgPath, bool duplicateCheck, const MailImporter::MessageStatus &status);
-    Q_REQUIRED_RESULT virtual bool importMessage(const KArchiveFile *file, const QString &folderPath, int &nbTotal, int &fileDone);
+    [[nodiscard]] virtual bool importMessage(const QString &folderName, const QString &msgPath, bool duplicateCheck, const MailImporter::MessageStatus &status);
+    [[nodiscard]] virtual bool importMessage(const KArchiveFile *file, const QString &folderPath, int &nbTotal, int &fileDone);
     virtual void clear();
     virtual void clearCountDuplicate();
-    Q_REQUIRED_RESULT virtual int countDuplicates() const;
-    Q_REQUIRED_RESULT virtual QString topLevelFolder() const;
+    [[nodiscard]] virtual int countDuplicates() const;
+    [[nodiscard]] virtual QString topLevelFolder() const;
 
 protected:
     MailImporter::FilterInfo *const mInfo;
