@@ -54,16 +54,13 @@ QString FilterClawsMail::localMailDirPath()
     QFile folderListFile(FilterClawsMail::defaultSettingsPath() + QLatin1String("/folderlist.xml"));
     if (folderListFile.exists()) {
         QDomDocument doc;
-        QString errorMsg;
-        int errorRow;
-        int errorCol;
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
         if (!folderListFile.open(QIODevice::ReadOnly)) {
             qCWarning(MAILIMPORTER_LOG) << "Impossible to open " << folderListFile.fileName();
         }
-#endif
-        if (!doc.setContent(&folderListFile, &errorMsg, &errorRow, &errorCol)) {
-            qCDebug(MAILIMPORTER_LOG) << "Unable to load document.Parse error in line " << errorRow << ", col " << errorCol << ": " << errorMsg;
+        const QDomDocument::ParseResult parseResult = doc.setContent(&folderListFile);
+        if (!parseResult) {
+            qCDebug(MAILIMPORTER_LOG) << "Unable to load document.Parse error in line " << parseResult.errorLine << ", col " << parseResult.errorColumn << ": "
+                                      << qPrintable(parseResult.errorMessage);
             return QString();
         }
         QDomElement settings = doc.documentElement();
