@@ -2,7 +2,7 @@
   filtersylpheed.cpp  -  Sylpheed maildir mail import
 
   SPDX-FileCopyrightText: 2005 Danny Kukawka <danny.kukawka@web.de>
-  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -59,19 +59,16 @@ QString FilterSylpheed::localMailDirPath()
     QFile folderListFile(FilterSylpheed::defaultSettingsPath() + QLatin1String("/folderlist.xml"));
     if (folderListFile.exists()) {
         QDomDocument doc;
-        QString errorMsg;
-        int errorRow;
-        int errorCol;
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
         if (!folderListFile.open(QIODevice::ReadOnly)) {
             qCWarning(MAILIMPORTER_LOG) << "Impossible to open " << folderListFile.fileName();
         }
-#endif
-        if (!doc.setContent(&folderListFile, &errorMsg, &errorRow, &errorCol)) {
-            qCDebug(MAILIMPORTER_LOG) << "Unable to load document.Parse error in line " << errorRow << ", col " << errorCol << ": " << errorMsg;
+        const QDomDocument::ParseResult parseResult = doc.setContent(&folderListFile);
+        if (!parseResult) {
+            qCDebug(MAILIMPORTER_LOG) << "Unable to load document.Parse error in line " << parseResult.errorLine << ", col " << parseResult.errorColumn << ": "
+                                      << qPrintable(parseResult.errorMessage);
             return QString();
         }
-        QDomElement settings = doc.documentElement();
+        const QDomElement settings = doc.documentElement();
 
         if (settings.isNull()) {
             return QString();
