@@ -1,14 +1,12 @@
 /*
-  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MESSAGESTATUS_H
-#define MESSAGESTATUS_H
+#pragma once
 
 #include "mailimporter_export.h"
-#include <QtGlobal>
 
 namespace MailImporter
 {
@@ -23,16 +21,16 @@ public:
     ~MessageStatus();
 
     void setRead(bool state);
-    Q_REQUIRED_RESULT bool isRead() const;
+    [[nodiscard]] bool isRead() const;
 
     void setDeleted(bool state);
-    Q_REQUIRED_RESULT bool isDeleted() const;
+    [[nodiscard]] bool isDeleted() const;
 
     void setReplied(bool state);
-    Q_REQUIRED_RESULT bool isReplied() const;
+    [[nodiscard]] bool isReplied() const;
 
     void setForwarded(bool state);
-    Q_REQUIRED_RESULT bool isForwarded() const;
+    [[nodiscard]] bool isForwarded() const;
 
 private:
     bool mRead = false;
@@ -41,4 +39,3 @@ private:
     bool mForwarded = false;
 };
 }
-#endif // MESSAGESTATUS_H
