@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -27,7 +27,7 @@ public:
     ~SelectThunderbirdProfileWidget();
 
     void fillProfile(const QMap<QString, QString> &map, const QString &defaultProfile);
-    Q_REQUIRED_RESULT QString selectedProfile() const;
+    [[nodiscard]] QString selectedProfile() const;
 
 private:
     Ui::SelectThunderbirdProfileWidget *const ui;
@@ -39,11 +39,10 @@ class MAILIMPORTER_TESTS_EXPORT SelectThunderbirdProfileDialog : public QDialog
 public:
     explicit SelectThunderbirdProfileDialog(QWidget *parent = nullptr);
     ~SelectThunderbirdProfileDialog();
-    Q_REQUIRED_RESULT QString selectedProfile() const;
+    [[nodiscard]] QString selectedProfile() const;
     void fillProfile(const QMap<QString, QString> &map, const QString &defaultProfile);
 
 private:
-    SelectThunderbirdProfileWidget *mSelectProfile = nullptr;
+    SelectThunderbirdProfileWidget *const mSelectProfile;
 };
 }
-
