@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -39,15 +39,15 @@ QString FilterImporterTest::topLevelFolder() const
 
 bool FilterImporterTest::importMessage(const KArchiveFile *file, const QString &folderPath, int &nbTotal, int &fileDone)
 {
-    Q_UNUSED(file);
-    Q_UNUSED(folderPath);
-    Q_UNUSED(nbTotal);
-    Q_UNUSED(fileDone);
+    Q_UNUSED(file)
+    Q_UNUSED(folderPath)
+    Q_UNUSED(nbTotal)
+    Q_UNUSED(fileDone)
 
     return false;
 }
 
-QVector<FilterImporterData> FilterImporterTest::filterImporterDataList() const
+QList<FilterImporterData> FilterImporterTest::filterImporterDataList() const
 {
     return mFilterImporterDataList;
 }
